--[[
-- 
-- Guilded Traders is the Trading control functionality for Guilded.
--
--]]

--[[
-- GuildedTraders
--     The main GuildedTraders object
--]]
GuildedTraders = {
	
    --[[
    -- onLoad()
    --     OnLoad setup function
    --]]
    onLoad = function()
		Guilded.cmdRegisterHandler(GUILDED_CMD_TRADERS_BUY_ADD, GuildedTraders.cmdHandler);
		Guilded.cmdRegisterHandler(GUILDED_CMD_TRADERS_BUY_DEL, GuildedTraders.cmdHandler);
		Guilded.cmdRegisterHandler(GUILDED_CMD_TRADERS_BUY_UPDATE, GuildedTraders.cmdHandler);
		Guilded.cmdRegisterHandler(GUILDED_CMD_TRADERS_SELL_ADD, GuildedTraders.cmdHandler);
		Guilded.cmdRegisterHandler(GUILDED_CMD_TRADERS_SELL_DEL, GuildedTraders.cmdHandler);
		Guilded.cmdRegisterHandler(GUILDED_CMD_TRADERS_SELL_UPDATE, GuildedTraders.cmdHandler);
		Guilded.cmdRegisterHandler(GUILDED_CMD_TRADERS_CRAFT_JOIN, GuildedTraders.cmdHandler);
		Guilded.cmdRegisterHandler(GUILDED_CMD_TRADERS_CRAFT_LEAVE, GuildedTraders.cmdHandler);
		Guilded.cmdRegisterHandler(GUILDED_CMD_TRADERS_CRAFT_UPDATE, GuildedTraders.cmdHandler);
	end;


    --[[
    -- onUnLoad()
    --     OnUnLoad setup function
    --]]
    onUnLoad = function()
		Guilded.cmdUnregisterHandler(GUILDED_CMD_TRADERS_BUY_ADD);
		Guilded.cmdUnregisterHandler(GUILDED_CMD_TRADERS_BUY_DEL);
		Guilded.cmdUnregisterHandler(GUILDED_CMD_TRADERS_BUY_UPDATE);
		Guilded.cmdUnregisterHandler(GUILDED_CMD_TRADERS_SELL_ADD);
		Guilded.cmdUnregisterHandler(GUILDED_CMD_TRADERS_SELL_DEL);
		Guilded.cmdUnregisterHandler(GUILDED_CMD_TRADERS_SELL_UPDATE);
		Guilded.cmdUnregisterHandler(GUILDED_CMD_TRADERS_CRAFT_JOIN);
		Guilded.cmdUnregisterHandler(GUILDED_CMD_TRADERS_CRAFT_LEAVE);
		Guilded.cmdUnregisterHandler(GUILDED_CMD_TRADERS_CRAFT_UPDATE);
	end;


    --[[
    -- cmdHandler( cmd )
    --     Guilded default command message handler
    --]]
    cmdHandler = function( cmd, msg, author )
        if ( cmd and author) then
		    if ( cmd == GUILDED_CMD_TRADERS_BUY_ADD and msg ) then
			    local link, texture, itemCount, locked, quality, price;
				local parseIterator = string.gfind(msg, GUILDED_PARSE_PATTERN);
				link = parseIterator();
				texture = parseIterator();
				itemCount = tonumber(parseIterator(), 10);
				locked = tonumber(parseIterator(), 10);
				quality = tonumber(parseIterator(), 10);
				price = tonumber(parseIterator(), 10);
  			    GuildedData.addItem(link, texture, itemCount, locked, quality, price, author);
				GuildedData.flagItem(link, author, "WTB", true);
		    elseif ( cmd == GUILDED_CMD_TRADERS_BUY_DEL and msg ) then
			    local link;
				local parseIterator = string.gfind(msg, GUILDED_PARSE_PATTERN);
				link = parseIterator();
				GuildedData.flagItem(link, author, "WTB", false);
				GuildedData.delItem(link, author);
		    elseif ( cmd == GUILDED_CMD_TRADERS_SELL_ADD and msg ) then
			    local link, texture, itemCount, locked, quality, price;
				local parseIterator = string.gfind(msg, GUILDED_PARSE_PATTERN);
				link = parseIterator();
				texture = parseIterator();
				itemCount = tonumber(parseIterator(), 10);
				locked = tonumber(parseIterator(), 10);
				quality = tonumber(parseIterator(), 10);
				price = tonumber(parseIterator(), 10);
  			    GuildedData.addItem(link, texture, itemCount, locked, quality, price, author);
				GuildedData.flagItem(link, author, "WTS", true);
		    elseif ( cmd == GUILDED_CMD_TRADERS_SELL_DEL and msg ) then
			    local link;
				local parseIterator = string.gfind(msg, GUILDED_PARSE_PATTERN);
				link = parseIterator();
				GuildedData.flagItem(link, author, "WTS", false);
				GuildedData.delItem(link, author);
		    elseif ( cmd == GUILDED_CMD_TRADERS_CRAFT_JOIN ) then
			    local prof, cat, level;
				local parseIterator = string.gfind(msg, GUILDED_PARSE_PATTERN);
				prof = parseIterator();
				level = parseIterator();
				cat = parseIterator();
  			    GuildedData.addCrafter(author, prof, cat, level);
				if ( author ~= UnitName("player") ) then
	                -- Broadcast player info for recently joined members
        	        if ( GuildedConfig.advertProf ) then
    	                GuildedTraders.advertiseProfessions(true, true);
            		end
				end
		    elseif ( cmd == GUILDED_CMD_TRADERS_CRAFT_LEAVE ) then
  			    GuildedData.delCrafter(author);
		    elseif ( cmd == GUILDED_CMD_TRADERS_CRAFT_UPDATE ) then
			    local prof, cat, level;
				local parseIterator = string.gfind(msg, GUILDED_PARSE_PATTERN);
				prof = parseIterator();
				level = parseIterator();
				cat = parseIterator();
  			    GuildedData.addCrafter(author, prof, cat, level);
            end
       		GuildedTradersGUI.onUpdate();
        end
    end;


    --[[
    -- onJoin()
    --     On join channel function
    --]]
    onJoin = function()
	    if ( GuildedConfig.advertProf ) then
    	    GuildedTraders.advertiseProfessions(true, false);
		end
		
		for i, item in GuildedConfig.stock do
		    if (item.wts) then
    		    GuildedTraders.sendBuySellItem(item.link, "WTS");
			end
			
		    if (item.wtb) then
    		    GuildedTraders.sendBuySellItem(item.link, "WTB");
			end
		end
	end;


    --[[
    -- onLeave()
    --     On leave channel function
    --]]
    onLeave = function()
	    GuildedTraders.advertiseProfessions(false, false);
		GuildedData.resetCrafters();
	end;


    --[[
    -- sendBuySellItem( link, stockType )
    --     Send Buy/Sell message.
    --]]
    sendBuySellItem = function(link, stockType)
	    local idx = GuildedConfig.findItem(link);
	    if (idx > 0) then
    	    local item = GuildedConfig.stock[idx];
			local lockValue;
			local cmd;

			if (item.locked) then
			    lockValue = 1;
			else
			    lockValue = 0;
			end

    	    if (stockType == "WTS") then
			    if (item.wts) then
            	    Guilded.sendCmdMsg(GUILDED_CMD_TRADERS_SELL_ADD..GUILDED_TOKEN..item.link..GUILDED_TOKEN..item.texture..GUILDED_TOKEN..item.itemCount..GUILDED_TOKEN..lockValue..GUILDED_TOKEN..item.quality..GUILDED_TOKEN..item.price);
				else
            	    Guilded.sendCmdMsg(GUILDED_CMD_TRADERS_SELL_DEL..GUILDED_TOKEN..item.link);
				end
		    elseif (stockType == "WTB") then
			    if (item.wtb) then
            	    Guilded.sendCmdMsg(GUILDED_CMD_TRADERS_BUY_ADD..GUILDED_TOKEN..item.link..GUILDED_TOKEN..item.texture..GUILDED_TOKEN..item.itemCount..GUILDED_TOKEN..lockValue..GUILDED_TOKEN..item.quality..GUILDED_TOKEN..item.price);
				else
            	    Guilded.sendCmdMsg(GUILDED_CMD_TRADERS_BUY_DEL..GUILDED_TOKEN..item.link);
				end
    		end
		end
	end;

    --[[
    -- advertiseProfessions( join, updateOnly )
    --     Advertise professions or cancel advert.
    --]]
    advertiseProfessions = function( join, updateOnly )
	    if ( join ) then
	    	local curTime = GetTime();
	    	if ( GuildedLastBroadcast ) and ( curTime - GuildedLastBroadcast < 10 ) then
	    		if ( Chronos ) then
	    			Chronos.scheduleByName("ADVERTPROF", 10, GuildedTraders.advertiseProfessions, join, updateOnly);
	    		elseif ( CosmosScheduleByName ) then
	    			CosmosScheduleByName("ADVERTPROF", 10, GuildedTraders.advertiseProfessions, join, updateOnly);
	    		end
	    		return;
	    	else
	    		GuildedLastBroadcast = curTime;
	    	end
	    	local spec = nil;
    		local numSkills = GetNumSkillLines();
    		local professionsFound = false;
    		local skillName, header, isExpanded, skillRank, numTempPoints, skillModifier, skillMaxRank, isAbandonable, stepCost, rankCost, minLevel, skillCostType;
    		for skillIdx = 1, numSkills do
    		    skillName, header, isExpanded, skillRank, numTempPoints, skillModifier, skillMaxRank, isAbandonable, stepCost, rankCost, minLevel, skillCostType = GetSkillLineInfo(skillIdx);
    			if ( header and ( skillName ==  TRADE_SKILLS ) ) then
    			    professionsFound = true;
    			elseif ( professionsFound ) then
    			    if ( header ) then
    				    break;
    				else
    					local cat = "";
    					if ( GuildedScornedLegionDKP_GetCategory ) then
    						cat = GuildedScornedLegionDKP_GetCategory();
    					end
    					if ( GuildedScornedLegion_TranslateProfession ) then
    						skillName = GuildedScornedLegion_TranslateProfession(skillName);
    					end
    					if ( GuildedScornedLegion_FindProfessionSpecialization ) then
		    				spec = GuildedScornedLegion_FindProfessionSpecialization(skillName);
			    			if ( spec ) then
			    				cat = cat.." "..spec;
			    			end
		    			end
					    if ( updateOnly ) then
		        		    Guilded.sendCmdMsg(GUILDED_CMD_TRADERS_CRAFT_UPDATE..GUILDED_TOKEN..skillName..GUILDED_TOKEN..skillRank..GUILDED_TOKEN..cat);
						else
		        		    Guilded.sendCmdMsg(GUILDED_CMD_TRADERS_CRAFT_JOIN..GUILDED_TOKEN..skillName..GUILDED_TOKEN..skillRank..GUILDED_TOKEN..cat);
						end
	    			end
	    		end
	    	end
		else
    	    Guilded.sendCmdMsg(GUILDED_CMD_TRADERS_CRAFT_LEAVE);
		end
	end;
};
