--[[
-- 
-- GuildedTradersGUI is the Guilded Traders sub-frame user interface
--
--]]
GUILDED_TRADERS_CRAFT_LIST_MEMBERS_TO_DISPLAY = 18;
GUILDED_TRADERS_CRAFT_LIST_FRAME_HEIGHT = 80;

GUILDED_TRADERS_ITEMS_TO_DISPLAY = 8;
GUILDED_TRADERS_ITEMS_FRAME_HEIGHT = 32;

GUILDED_TRADERS_ITEM_PATTERN = "|c(%x+)|H(item:%d+:%d+:%d+:%d+)|h%[(.-)%]|h|r";

MoneyTypeInfo["GUILDED"] = {
	UpdateFunc = function()
		return this.staticMoney;
	end,
	showSmallerCoins = 1,
	collapse = nil,
	truncateSmallCoins = nil,
};

GuildedTradersGUI = {
    containerItemClickedOriginal = nil;
	merchantItemClickedOriginal = nil;
	inventoryItemClickedOriginal = nil;
	inspectInventoryItemClickedOriginal = nil;
	bankItemButtonClickedOriginal = nil;
	tradeSkillButtonClickedOriginal = nil;
	auctionButtonClickedOriginal = nil;
	auctionBrowseButtonClickedOriginal = nil;
	auctionBidButtonClickedOriginal = nil;
	aioiItemButtonClickedOriginal = nil;
	myBankItemButtonClickedOriginal = nil;
	myInventoryButtonClickedOriginal = nil;

    --[[
    -- onLoad()
    --     OnLoad initialisation function
    --]]
    onLoad = function()
		GuildedTraders.onLoad();

    	PanelTemplates_SetNumTabs(this, 4);
		GuildedTradersFrame.selectedTab = 4;
		
	    PanelTemplates_UpdateTabs(GuildedTradersFrame);
		
        -- Hook ContainerFrameItemButton_OnClick
		GuildedTradersGUI.containerItemClickedOriginal = ContainerFrameItemButton_OnClick;
		ContainerFrameItemButton_OnClick = GuildedTradersGUI.containerItemClicked;

        -- Hook MerchantItemButton_OnClick
		GuildedTradersGUI.merchantItemClickedOriginal = MerchantItemButton_OnClick;
		MerchantItemButton_OnClick = GuildedTradersGUI.merchantItemClicked;

        -- Hook PaperDollItemSlotButton_OnClick
		GuildedTradersGUI.inventoryItemClickedOriginal = PaperDollItemSlotButton_OnClick;
		PaperDollItemSlotButton_OnClick = GuildedTradersGUI.inventoryItemClicked;

        -- Hook PaperDollItemSlotButton_OnClick
		GuildedTradersGUI.inspectInventoryItemClickedOriginal = InspectPaperDollItemSlotButton_OnClick;
		InspectPaperDollItemSlotButton_OnClick = GuildedTradersGUI.inspectInventoryItemClicked;

        -- Hook BankFrameItemButtonGeneric_OnClick
		GuildedTradersGUI.bankItemButtonClickedOriginal = BankFrameItemButtonGeneric_OnClick;
		BankFrameItemButtonGeneric_OnClick = GuildedTradersGUI.bankItemButtonClicked;

        -- Hook TradeSkillSkillButton_OnClick
    	GuildedTradersGUI.tradeSkillButtonClickedOriginal = TradeSkillSkillButton_OnClick;
   		TradeSkillSkillButton_OnClick = GuildedTradersGUI.tradeSkillButtonClicked;

        -- Hook AuctionsButton_OnClick
		GuildedTradersGUI.auctionButtonClickedOriginal = AuctionsButton_OnClick;
		AuctionsButton_OnClick = GuildedTradersGUI.auctionButtonClicked;

        -- Hook BrowseButton_OnClick
		GuildedTradersGUI.auctionBrowseButtonClickedOriginal = BrowseButton_OnClick;
		BrowseButton_OnClick = GuildedTradersGUI.auctionBrowseButtonClicked;

        -- Hook BidButton_OnClick
		GuildedTradersGUI.auctionBidButtonClickedOriginal = BidButton_OnClick;
		BidButton_OnClick = GuildedTradersGUI.auctionBidButtonClicked;

        -- Hook AllInOneInventoryFrameItemButton_OnClick
		if (AllInOneInventoryFrameItemButton_OnClick) then
    		GuildedTradersGUI.aioiItemButtonClickedOriginal = AllInOneInventoryFrameItemButton_OnClick;
	    	AllInOneInventoryFrameItemButton_OnClick = GuildedTradersGUI.aioiItemButtonClicked;
		end

        -- Hook MyBankFrameItemButton_OnClick
		if (MyBankFrameItemButton_OnClick) then
    		GuildedTradersGUI.myBankItemButtonClickedOriginal = MyBankFrameItemButton_OnClick;
	    	MyBankFrameItemButton_OnClick = GuildedTradersGUI.myBankItemButtonClicked;
        end

        -- Hook MyInventoryFrameItemButton_OnClick
		if (MyInventoryFrameItemButton_OnClick) then
    		GuildedTradersGUI.myInventoryButtonClickedOriginal = MyInventoryFrameItemButton_OnClick;
	    	MyInventoryFrameItemButton_OnClick = GuildedTradersGUI.myInventoryButtonClicked;
        end
		
	end;


	lastUpdate = nil;

    --[[
    -- onUpdate()
    --     Update the Traders sub-frame display
    --]]
    onUpdate = function()
    	local curTime = GetTime();
    	if ( GuildedTradersGUI.lastUpdate ) and ( curTime - GuildedTradersGUI.lastUpdate < 10 ) then
    		if ( Chronos ) then
    			Chronos.scheduleByName("GUILDEDGUIUPDATE", 5, GuildedTradersGUI.onUpdate);
    		elseif ( CosmosScheduleByName ) then
    			CosmosScheduleByName("GUILDEDGUIUPDATE", 5, GuildedTradersGUI.onUpdate);
    		end
    		return;
    	else
    		GuildedTradersGUI.lastUpdate = curTime;
    	end
	    if ( (GuildedTradersFrame.selectedTab == 1)
	      or (GuildedTradersFrame.selectedTab == 2) ) then
            GuildedTradersFrameCraft:Hide();
            GuildedTradersFrameStock:Hide();
            GuildedTradersFrameBuySell:Show();
    	    GuildedTradersFrameRemoveButton:Disable();
            GuildedTradersGUI.onUpdateBuySell();
		elseif (GuildedTradersFrame.selectedTab == 3) then
            GuildedTradersFrameCraft:Hide();
            GuildedTradersFrameBuySell:Hide();
            GuildedTradersFrameStock:Show();
    	    GuildedTradersFrameWhisperButton:Disable();
            GuildedTradersGUI.onUpdateStock();
		elseif (GuildedTradersFrame.selectedTab == 4) then
            GuildedTradersFrameBuySell:Hide();
            GuildedTradersFrameStock:Hide();
            GuildedTradersFrameCraft:Show();
    	    GuildedTradersFrameRemoveButton:Disable();
            GuildedTradersGUI.onUpdateCrafts();
		end
	end;


    --[[
    -- onUpdateBuySell()
    --     Update the Traders Buy/Sell sub-frame display
    --]]
    onUpdateBuySell = function()
    	local button;
    	local buySellListOffset = FauxScrollFrame_GetOffset(GuildedTradersFrameBuySellScroll);
    	local index;
		local stockTable;
		local searchPat = GuildedTradersFrameBuySellSearchEditBox:GetText();
		
		
	    if (GuildedTradersFrame.selectedTab == 1) then
		    stockTable = GuildedData.getItemTable("WTB", searchPat);
		elseif (GuildedTradersFrame.selectedTab == 2) then
		    stockTable = GuildedData.getItemTable("WTS", searchPat);
		else
		    return;
		end

		-- Check if selected item has been removed.
		if ( GuildedData.findItem(GuildedTradersFrameBuySell.selectedLink, GuildedTradersFrameBuySell.selectedOwner) < 0 ) then
		    GuildedTradersFrameBuySell.selectedLink = nil;
    	    GuildedTradersFrameBuySell.selectedOwner = nil;
		end
		GuildedTradersFrameBuySell.selectedMember = nil;
		
		local i = 1;
    	for index = 1 + buySellListOffset, buySellListOffset + GUILDED_TRADERS_ITEMS_TO_DISPLAY do
		    if ( index > table.getn(stockTable) ) then
			    break;
			end
		    item = stockTable[index];

			local button = getglobal("GuildedTradersFrameBuySellButton"..i);
    		button.index = index;
			button.link = item.link;
			button.owner = item.owner;

			local itemButton = getglobal("GuildedTradersFrameBuySellButton"..i.."Item");
			SetItemButtonCount(itemButton, item.itemCount);
			SetItemButtonTexture(itemButton, item.texture);

			local itemText = getglobal("GuildedTradersFrameBuySellButton"..i.."Name");
			itemText:SetText(string.gsub(item.link, GUILDED_TRADERS_ITEM_PATTERN, "|c%1%3"));
			
			local itemOwner = getglobal("GuildedTradersFrameBuySellButton"..i.."Owner");
			itemOwner:SetText(item.owner);
			
			local itemCash = getglobal("GuildedTradersFrameBuySellButton"..i.."MoneyFrame");
			MoneyFrame_Update(itemCash:GetName(), item.price);
			
    		-- Highlight the correct who
			if ( ( GuildedTradersFrameBuySell.selectedLink == item.link ) 
			 and ( GuildedTradersFrameBuySell.selectedOwner == item.owner ) ) then
			    GuildedTradersFrameBuySell.selectedMember = index;
			end

	    	if ( GuildedTradersFrameBuySell.selectedMember == index ) then
		    	button:LockHighlight();
    		else
	    		button:UnlockHighlight();
		    end
		
   			button:Show();
			
			i = i + 1;
			if (i > GUILDED_TRADERS_ITEMS_TO_DISPLAY) then
			    break;
		    end
		end
		
		while ( i <= GUILDED_TRADERS_ITEMS_TO_DISPLAY ) do
		    getglobal("GuildedTradersFrameBuySellButton"..i):Hide();
			i = i + 1;
		end

    	if ( not GuildedTradersFrameBuySell.selectedMember ) then
		    GuildedTradersFrameWhisperButton:Disable();
	    else
		    GuildedTradersFrameWhisperButton:Enable();
	    end

    	-- ScrollFrame update
		if (table.getn(stockTable) <= GUILDED_TRADERS_ITEMS_TO_DISPLAY) then
    	    FauxScrollFrame_Update(GuildedTradersFrameBuySellScroll, 1, 0, 0 );
		else
    	    FauxScrollFrame_Update(GuildedTradersFrameBuySellScroll, table.getn(stockTable), GUILDED_TRADERS_ITEMS_TO_DISPLAY, GUILDED_TRADERS_ITEMS_FRAME_HEIGHT );
		end
	end;


    --[[
    -- onUpdateStock()
    --     Update the Traders Stock sub-frame display
    --]]
    onUpdateStock = function()
    	local button;
    	local stockListOffset = FauxScrollFrame_GetOffset(GuildedTradersFrameItemScroll);
    	local index;

		-- Check if selected member has left.
		if ( GuildedConfig.findItem(GuildedTradersFrameStock.selectedLink) < 0 ) then
		    GuildedTradersFrameStock.selectedLink = nil;
    	    GuildedTradersFrameStock.selectedOwner = nil;
		end
		GuildedTradersFrameStock.selectedMember = nil;
		
		local i = 1;
    	for index = 1 + stockListOffset, stockListOffset + GUILDED_TRADERS_ITEMS_TO_DISPLAY do
		    if ( index > GuildedConfig.numStock ) then
			    break;
			end
		    item = GuildedConfig.stock[index];

			local button = getglobal("GuildedTradersFrameItemButton"..i);
    		button.index = index;
			button.link = item.link;
			button.owner = UnitName("player");

			local itemButton = getglobal("GuildedTradersFrameItemButton"..i.."Item");
			SetItemButtonCount(itemButton, item.itemCount);
			SetItemButtonTexture(itemButton, item.texture);

			local itemText = getglobal("GuildedTradersFrameItemButton"..i.."Name");
			itemText:SetText(string.gsub(item.link, GUILDED_TRADERS_ITEM_PATTERN, "|c%1%3"));
			
			local itemOwner = getglobal("GuildedTradersFrameItemButton"..i.."Owner");
			itemOwner:SetText(UnitName("player"));
			
			local itemCash = getglobal("GuildedTradersFrameItemButton"..i.."MoneyFrame");
			MoneyFrame_Update(itemCash:GetName(), item.price);

			local itemOwner = getglobal("GuildedTradersFrameItemButton"..i.."WTSTickboxTickbox");
			itemOwner:SetChecked(item.wts);
			
			local itemOwner = getglobal("GuildedTradersFrameItemButton"..i.."WTBTickboxTickbox");
			itemOwner:SetChecked(item.wtb);
			
    		-- Highlight the correct who
			if ( GuildedTradersFrameStock.selectedLink == item.link ) then
			    GuildedTradersFrameStock.selectedMember = index;
			end

	    	if ( GuildedTradersFrameStock.selectedMember == index ) then
		    	button:LockHighlight();
    		else
	    		button:UnlockHighlight();
		    end
		
   			button:Show();
			
			i = i + 1;
			if (i > GUILDED_TRADERS_ITEMS_TO_DISPLAY) then
			    break;
		    end
		end
		
		while ( i <= GUILDED_TRADERS_ITEMS_TO_DISPLAY ) do
		    getglobal("GuildedTradersFrameItemButton"..i):Hide();
			i = i + 1;
		end

    	if ( not GuildedTradersFrameStock.selectedMember ) then
		    GuildedTradersFrameRemoveButton:Disable();
	    else
		    GuildedTradersFrameRemoveButton:Enable();
	    end

    	-- ScrollFrame update
		if (GuildedConfig.numStock <= GUILDED_TRADERS_ITEMS_TO_DISPLAY) then
    	    FauxScrollFrame_Update(GuildedTradersFrameItemScroll, 1, 0, 0 );
		else
    	    FauxScrollFrame_Update(GuildedTradersFrameItemScroll, GuildedConfig.numStock, GUILDED_TRADERS_ITEMS_TO_DISPLAY, GUILDED_TRADERS_ITEMS_FRAME_HEIGHT );
		end
	end;


    --[[
    -- onUpdateCrafts()
    --     Update the Traders Craft sub-frame display
    --]]
    onUpdateCrafts = function()
    	local button;
    	local craftersListOffset = FauxScrollFrame_GetOffset(GuildedTradersFrameCraftScroll);
    	local index;
    	local showScrollBar = nil;
    	if ( GuildedData.numCrafters > GUILDED_TRADERS_CRAFT_LIST_MEMBERS_TO_DISPLAY ) then
	    	showScrollBar = 1;
	    end

		-- Check if selected member has left.
		if ( GuildedData.findCrafter(GuildedTradersFrameCraft.selectedName) < 0 ) then
		    GuildedTradersFrameCraft.selectedName = nil;
		end
	    GuildedTradersFrameCraft.selectedMember = nil;
		
		local i = 1;
    	for index = 1 + craftersListOffset, craftersListOffset + GUILDED_TRADERS_CRAFT_LIST_MEMBERS_TO_DISPLAY do
		    if ( index > GuildedData.numCrafters ) then
			    break;
			end
		    crafter = GuildedData.crafters[index];
    		button = getglobal("GuildedTradersFrameButton"..i);
    		button.index = index;
    		getglobal("GuildedTradersFrameButton"..i.."Name"):SetText(crafter.name);
	    	getglobal("GuildedTradersFrameButton"..i.."Prof"):SetText(crafter.prof);
		    getglobal("GuildedTradersFrameButton"..i.."Level"):SetText(crafter.level);
	    	getglobal("GuildedTradersFrameButton"..i.."Cat"):SetText(crafter.cat);
		
    		-- If need scrollbar resize columns
	    	if ( showScrollBar ) then
		    	getglobal("GuildedTradersFrameButton"..i.."Prof"):SetWidth(95);
    		else
	    		getglobal("GuildedTradersFrameButton"..i.."Prof"):SetWidth(110);
		    end
			
			if ( ( GuildedTradersFrameCraft.selectedName == crafter.name ) 
			 and ( GuildedTradersFrameCraft.selectedProf == crafter.prof ) ) then
			    GuildedTradersFrameCraft.selectedMember = index;
			end

    		-- Highlight the correct who
	    	if ( GuildedTradersFrameCraft.selectedMember == index ) then
		    	button:LockHighlight();
    		else
	    		button:UnlockHighlight();
		    end
		
   			button:Show();
			
			i = i + 1;
			if (i > GUILDED_TRADERS_CRAFT_LIST_MEMBERS_TO_DISPLAY) then
			    break;
		    end
		end
		
		while ( i <= GUILDED_TRADERS_CRAFT_LIST_MEMBERS_TO_DISPLAY ) do
		    getglobal("GuildedTradersFrameButton"..i):Hide();
			i = i + 1;
		end

    	if ( not GuildedTradersFrameCraft.selectedMember ) then
		    GuildedTradersFrameWhisperButton:Disable();
	    else
	    	GuildedTradersFrameWhisperButton:Enable();
	    end

    	-- If need scrollbar resize column headers
    	if ( showScrollBar ) then
	    	GuildedSetColumnWidth(105, GuildedTradersFrameCraftColumnHeader2);
    	else
	    	GuildedSetColumnWidth(120, GuildedTradersFrameCraftColumnHeader2);
    	end

    	-- ScrollFrame update
	    FauxScrollFrame_Update(GuildedTradersFrameCraftScroll, GuildedData.numCrafters, GUILDED_TRADERS_CRAFT_LIST_MEMBERS_TO_DISPLAY, GUILDED_TRADERS_CRAFT_LIST_FRAME_HEIGHT );
	end;


    --[[
    -- searchButtonOnClick()
    --     Apply the search string to all items.
    --]]
    searchButtonOnClick = function()
	    FauxScrollFrame_SetOffset(GuildedTradersFrameBuySellScroll, 0);
        GuildedTradersGUI.onUpdateBuySell();
    end;

    --[[
    -- addStockItem( link, texture, itemCount, locked, quality, price )
    --     Add item to stock data and auto add to WTS/WTB page.
    --]]
    addStockItem = function(link, texture, itemCount, locked, quality, price)
		GuildedConfig.addItem(link, texture, itemCount, locked, quality, price);

        if (GuildedTradersFrameBuySell:IsVisible()) then
    	    if (GuildedTradersFrame.selectedTab == 1) then
    			GuildedConfig.flagItem(link, "WTB", true);
        		GuildedTraders.sendBuySellItem(link, "WTB");
            elseif (GuildedTradersFrame.selectedTab == 2) then
    			GuildedConfig.flagItem(link, "WTS", true);
        		GuildedTraders.sendBuySellItem(link, "WTS");
            end
        end
		GuildedTradersGUI.onUpdateStock();
    end;


    --[[
    -- itemButtonOnClick()
    --     Click the stock item button
    --]]
    itemButtonOnClick = function(button, frame)
		if ( IsShiftKeyDown() ) then
        	if ( ChatFrameEditBox:IsVisible() ) then
        		ChatFrameEditBox:Insert(this.link);
	        end
		else
			frame.selectedLink = this.link;
			frame.selectedOwner = this.owner;
   		    GuildedTradersGUI.onUpdate();
		end
    end;


    --[[
    -- itemButtonOnEnter()
    --     Show the item tooltip
    --]]
    itemButtonOnEnter = function()
		GameTooltip:SetOwner(this, "ANCHOR_RIGHT");
		GameTooltip:SetHyperlink(string.gsub(this:GetParent().link, GUILDED_TRADERS_ITEM_PATTERN, "%2"));
		GameTooltip:Show();
    end;


    --[[
    -- onCraftButtonClick()
    --     Select the Guilded crafter that has been clicked on
    --]]
    onCraftButtonClick = function()
    	GuildedTradersFrameCraft.selectedMember = getglobal("GuildedTradersFrameButton"..this:GetID()).index;
	    GuildedTradersFrameCraft.selectedName = getglobal("GuildedTradersFrameButton"..this:GetID().."Name"):GetText();
	    GuildedTradersFrameCraft.selectedProf = getglobal("GuildedTradersFrameButton"..this:GetID().."Prof"):GetText();
    	GuildedTradersGUI.onUpdate();
    end;
    
    --[[
    -- whisperButtonOnClick()
    --     Click the whisper item button
    --]]
    whisperButtonOnClick = function()
	    local name;
		local msg = "";
	    if (GuildedTradersFrame.selectedTab == 1) then
		      name = GuildedTradersFrameBuySell.selectedOwner;
			  msg = format(GUILDED_TRADERS_WHISPER_ITEM_WTB, GuildedTradersFrameBuySell.selectedLink);
		elseif (GuildedTradersFrame.selectedTab == 2) then
		      name = GuildedTradersFrameBuySell.selectedOwner;
			  msg = format(GUILDED_TRADERS_WHISPER_ITEM_WTS, GuildedTradersFrameBuySell.selectedLink);
		elseif (GuildedTradersFrame.selectedTab == 3) then
		    return;
		elseif (GuildedTradersFrame.selectedTab == 4) then
		      name = GuildedTradersFrameCraft.selectedName;
			  msg = GUILDED_TRADERS_WHISPER_CRAFTER;
		end

	    if ( not name ) then
		    return;
		end
       	if ( not ChatFrameEditBox:IsVisible() ) then
       		ChatFrame_OpenChat("/w "..name.." "..msg);
        else
            ChatFrameEditBox:SetText("/w "..name.." "..msg);
        end
        ChatEdit_ParseText(ChatFrame1.editBox, 0);
    end;


    --[[
    -- removeButtonOnClick()
    --     Click the remove item button
    --]]
    removeButtonOnClick = function()
		if (GuildedTradersFrameStock.selectedLink) then
		    GuildedConfig.flagItem(GuildedTradersFrameStock.selectedLink, "WTS", false);
   		    GuildedTraders.sendBuySellItem(GuildedTradersFrameStock.selectedLink, "WTS");
		    GuildedConfig.flagItem(GuildedTradersFrameStock.selectedLink, "WTB", false);
   		    GuildedTraders.sendBuySellItem(GuildedTradersFrameStock.selectedLink, "WTB");
		    GuildedConfig.delItem(GuildedTradersFrameStock.selectedLink);
		    GuildedTradersFrameRemoveButton:Disable();
			GuildedTradersGUI.onUpdateStock();
		end
    end;


    --[[
    -- inputMoneyFrameOKButton()
    --     Click the stock item button
    --]]
    inputMoneyFrameOKButton = function()
	    if ( (GuildedTradersFrameInputMoneyFrame.moneyFrame ~= nil) and (GuildedTradersFrameInputMoneyFrame.moneyFrame.staticMoney ~= nil) ) then
		    local idx = GuildedTradersFrameInputMoneyFrame.moneyFrame:GetParent().index;
   		    GuildedConfig.stock[idx].price = MoneyInputFrame_GetCopper(GuildedTradersFrameInputMoneyFrameCash);
            local count = GuildedTradersFrameInputMoneyFrameQuantity:GetNumber();
            if (count ~= nul) then
				GuildedConfig.stock[idx].itemCount = count;
            end
			if (GuildedConfig.stock[idx].wts) then
    			GuildedTraders.sendBuySellItem(GuildedConfig.stock[idx].link, "WTS");
			end
			if (GuildedConfig.stock[idx].wtb) then
    			GuildedTraders.sendBuySellItem(GuildedConfig.stock[idx].link, "WTB");
			end
		end
		GuildedTradersFrameInputMoneyFrame:Hide();
		GuildedTradersGUI.onUpdate();
    end;


    --[[
    -- isAddStockState(button)
    --     Check if the current state of keys and mouse button is for the Guilded Add Stock event
    --]]
    isAddStockState = function(button, checkVisible)
    	if ( checkVisible and IsControlKeyDown() and (button == "LeftButton") ) then
            return true;
        else
            return false;
        end
    end;

	
    --[[
    -- containerItemClicked(button, ignoreShift)
    --     Hook function for ContainerFrameItemButton_OnClick
    --]]
    containerItemClicked = function(button, ignoreShift)
    	if ( GuildedTradersGUI.isAddStockState(button, GuildedTradersFrame:IsVisible()) ) then
		    local texture, itemCount, locked, quality = GetContainerItemInfo(this:GetParent():GetID(), this:GetID());
			local link = GetContainerItemLink(this:GetParent():GetID(), this:GetID());
			GuildedTradersGUI.addStockItem(link, texture, itemCount, locked, quality, 1);
			return;
		end
	
    	GuildedTradersGUI.containerItemClickedOriginal(button, ignoreShift);
    end;


    --[[
    -- merchantItemClicked(button)
    --     Hook function for MerchantItemButton_OnClick
    --]]
    merchantItemClicked = function(button)
    	if ( GuildedTradersGUI.isAddStockState(button, GuildedTradersFrame:IsVisible()) ) then
		    local name, texture, price, itemCount, numAvailable, isUsable = GetMerchantItemInfo(this:GetID());
			local link = GetMerchantItemLink(this:GetID());
			GuildedTradersGUI.addStockItem(link, texture, itemCount, 0, 0, price);
			return;
		end
	
    	GuildedTradersGUI.merchantItemClickedOriginal(button);
    end;


    --[[
    -- inventoryItemClicked(button, ignoreShift)
    --     Hook function for PaperDollItemSlotButton_OnClick
    --]]
    inventoryItemClicked = function(button, ignoreShift)
    	if ( GuildedTradersGUI.isAddStockState(button, GuildedTradersFrame:IsVisible()) ) then
		    local texture = GetInventoryItemTexture("player", this:GetID());
			local link = GetInventoryItemLink("player", this:GetID());
			GuildedTradersGUI.addStockItem(link, texture, 1, 0, 0, 1);
			return;
		end
	
    	GuildedTradersGUI.inventoryItemClickedOriginal(button, ignoreShift);
    end;


    --[[
    -- inspectInventoryItemClicked(button, ignoreShift)
    --     Hook function for InspectPaperDollItemSlotButton_OnClick
    --]]
    inspectInventoryItemClicked = function(button, ignoreShift)
    	if ( GuildedTradersGUI.isAddStockState(button, GuildedTradersFrame:IsVisible()) ) then
		    local texture = GetInventoryItemTexture(InspectFrame.unit, this:GetID());
			local link = GetInventoryItemLink(InspectFrame.unit, this:GetID());
			GuildedTradersGUI.addStockItem(link, texture, 1, 0, 0, 1);
			return;
		end
	
    	GuildedTradersGUI.inspectInventoryItemClickedOriginal(button, ignoreShift);
    end;


    --[[
    -- bankItemButtonClicked(button)
    --     Hook function for BankFrameItemButtonGeneric_OnClick
    --]]
    bankItemButtonClicked = function(button)
    	if ( GuildedTradersGUI.isAddStockState(button, GuildedTradersFrame:IsVisible()) ) then
		    local texture, itemCount, locked, quality = GetContainerItemInfo(BANK_CONTAINER, this:GetID());
			local link = GetContainerItemLink(BANK_CONTAINER, this:GetID());
			GuildedTradersGUI.addStockItem(link, texture, itemCount, locked, quality, 1);
			return;
		end
	
    	GuildedTradersGUI.bankItemButtonClickedOriginal(button);
    end;


    --[[
    -- tradeSkillButtonClicked(button)
    --     Hook function for TradeSkillSkillButton_OnClick
    --]]
    tradeSkillButtonClicked = function(button)
    	if ( GuildedTradersGUI.isAddStockState(button, GuildedTradersFrame:IsVisible()) ) then
    		local texture = GetTradeSkillIcon(this:GetID());
	    	local link = GetTradeSkillItemLink(this:GetID());
			GuildedTradersGUI.addStockItem(link, texture, 1, 0, 0, 1);
			return;
		end
	
    	GuildedTradersGUI.tradeSkillButtonClickedOriginal(button);
    end;


    --[[
    -- auctionButtonClicked(button)
    --     Hook function for AuctionsButton_OnClick
    --]]
    auctionButtonClicked = function(button)
    	if ( GuildedTradersGUI.isAddStockState(arg1, true) ) then
			local name, texture, itemCount, quality, canUse, level, minBid, minIncrement, buyoutPrice, bidAmount, highBidder, owner =  GetAuctionItemInfo("owner", this:GetParent():GetID() + FauxScrollFrame_GetOffset(AuctionsScrollFrame));
            local link = GetAuctionItemLink("owner", this:GetParent():GetID() + FauxScrollFrame_GetOffset(AuctionsScrollFrame));
			GuildedTradersGUI.addStockItem(link, texture, itemCount, 0, quality, bidAmount);
			return;
		end
	
    	GuildedTradersGUI.auctionButtonClickedOriginal(button);
    end;


    --[[
    -- auctionBrowseButtonClicked(button)
    --     Hook function for BrowseButton_OnClick
    --]]
    auctionBrowseButtonClicked = function(button)
    	if ( GuildedTradersGUI.isAddStockState(arg1, true) ) then
			local name, texture, itemCount, quality, canUse, level, minBid, minIncrement, buyoutPrice, bidAmount, highBidder, owner =  GetAuctionItemInfo("list", this:GetParent():GetID() + FauxScrollFrame_GetOffset(BrowseScrollFrame));
            local link = GetAuctionItemLink("list", this:GetParent():GetID() + FauxScrollFrame_GetOffset(BrowseScrollFrame));
			GuildedTradersGUI.addStockItem(link, texture, itemCount, 0, quality, bidAmount);
			return;
		end
	
    	GuildedTradersGUI.auctionBrowseButtonClickedOriginal(button);
    end;


    --[[
    -- auctionBidButtonClicked(button)
    --     Hook function for BidButton_OnClick
    --]]
    auctionBidButtonClicked = function(button)
    	if ( GuildedTradersGUI.isAddStockState(arg1, true) ) then
			local name, texture, itemCount, quality, canUse, level, minBid, minIncrement, buyoutPrice, bidAmount, highBidder, owner =  GetAuctionItemInfo("bidder", this:GetParent():GetID() + FauxScrollFrame_GetOffset(BidScrollFrame));
            local link = GetAuctionItemLink("bidder", this:GetParent():GetID() + FauxScrollFrame_GetOffset(BidScrollFrame));
			GuildedTradersGUI.addStockItem(link, texture, itemCount, 0, quality, bidAmount);
			return;
		end
	
    	GuildedTradersGUI.auctionBidButtonClickedOriginal(button);
    end;


    --[[
    -- aioiItemButtonClicked(button)
    --     Hook function for AllInOneInventoryFrameItemButton_OnClick
    --]]
    aioiItemButtonClicked = function(button)
    	if ( GuildedTradersGUI.isAddStockState(button, GuildedTradersFrame:IsVisible()) and AllInOneInventory_GetIdAsBagSlot) then
		    local bag, slot = AllInOneInventory_GetIdAsBagSlot(this:GetID());
		    local texture, itemCount, locked, quality = GetContainerItemInfo(bag, slot);
			local link = GetContainerItemLink(bag, slot);
			GuildedTradersGUI.addStockItem(link, texture, itemCount, locked, quality, 1);
			return;
		end
	
    	GuildedTradersGUI.aioiItemButtonClickedOriginal(button);
    end;

	
	--[[
    -- myBankItemButtonClicked(button)
    --     Hook function for MyBankFrameItemButton_OnClick
    --]]
    myBankItemButtonClicked = function(button, ignoreShift)
    	if ( GuildedTradersGUI.isAddStockState(button, GuildedTradersFrame:IsVisible()) ) then
		    local texture, itemCount, locked, quality = GetContainerItemInfo(this.bagIndex, this.itemIndex);
			local link = MyBank_GetBag(this.bagIndex)[this.itemIndex]["l"];
			GuildedTradersGUI.addStockItem(link, texture, itemCount, locked, quality, 1);
			return;
		end
	
    	GuildedTradersGUI.myBankItemButtonClickedOriginal(button, ignoreShift);
    end;



    --[[
    -- myInventoryButtonClicked(button)
    --     Hook function for MyInventoryFrameItemButton_OnClick
    --]]
    myInventoryButtonClicked = function(button, ignoreShift)
    	if ( GuildedTradersGUI.isAddStockState(button, GuildedTradersFrame:IsVisible()) and MyInventory_GetIdAsBagSlot) then
		    message("MyInv2");
		    local bag, slot = MyInventory_GetIdAsBagSlot(this:GetID());
		    local texture, itemCount, locked, quality = GetContainerItemInfo(bag, slot);
			local link = GetContainerItemLink(bag, slot);
			GuildedTradersGUI.addStockItem(link, texture, itemCount, locked, quality, 1);
			return;
		end
	
    	GuildedTradersGUI.myInventoryButtonClickedOriginal(button, ignoreShift);
    end;

	
};
